@@ -1,6 +1,4 @@
 # Copyright (c) lobsterpy development team
 # Distributed under the terms of a BSD 3-Clause "New" or "Revised" License
 
-"""
-This package provides the modules for analyzing COHPs
-"""
+"""This package provides the modules for analyzing COHPs."""
